@@ -24,12 +24,10 @@
 
 #include <KLocalizedString>
 
-// FIXME: vhanda
-//static const KCatalogLoader loader("kfilemetadata");
-
 using namespace KFileMetaData;
 
-class PropertyInfo::Private {
+class Q_DECL_HIDDEN PropertyInfo::Private
+{
 public:
     Property::Property prop;
     QString name;
@@ -133,7 +131,7 @@ PropertyInfo::PropertyInfo(Property::Property property)
 
         case Property::Generator:
             d->name = QStringLiteral("generator");
-            d->displayName = i18nc("@label", "Software used to Generate the document");
+            d->displayName = i18nc("@label", "Document Generated By");
             d->valueType = QVariant::String;
             d->shouldBeIndexed = false;
             break;
@@ -355,6 +353,12 @@ PropertyInfo::PropertyInfo(Property::Property property)
             d->valueType = QVariant::Int;
             break;
 
+        case Property::DiscNumber:
+            d->name = QStringLiteral("discNumber");
+            d->displayName = i18nc("@label music disc number", "Disc Number");
+            d->valueType = QVariant::Int;
+            break;
+
         case Property::Width:
             d->name = QStringLiteral("width");
             d->displayName = i18nc("@label", "Width");
@@ -411,6 +415,34 @@ PropertyInfo::PropertyInfo(Property::Property property)
             d->shouldBeIndexed = false;
             break;
 
+        case Property::OriginUrl:
+            d->name = QStringLiteral("originUrl");
+            d->displayName = i18nc("@label the URL a file was originally downloded from", "Downloaded From");
+            d->valueType = QVariant::Url;
+            d->shouldBeIndexed = false;
+            break;
+
+        case Property::OriginEmailSubject:
+            d->name = QStringLiteral("originEmailSubject");
+            d->displayName = i18nc("@label the subject of an email this file was attached to", "E-Mail Attachment Subject");
+            d->valueType = QVariant::String;
+            d->shouldBeIndexed = false;
+            break;
+
+        case Property::OriginEmailSender:
+            d->name = QStringLiteral("originEmailSender");
+            d->displayName = i18nc("@label the sender of an email this file was attached to", "E-Mail Attachment Sender");
+            d->valueType = QVariant::String;
+            d->shouldBeIndexed = false;
+            break;
+
+        case Property::OriginEmailMessageId:
+            d->name = QStringLiteral("originEmailMessageId");
+            d->displayName = i18nc("@label the message ID of an email this file was attached to", "E-Mail Attachment Message ID");
+            d->valueType = QVariant::String;
+            d->shouldBeIndexed = false;
+            break;
+
         case Property::PropertyCount: // To silence the compiler.
             break;
 
@@ -480,6 +512,7 @@ PropertyInfo PropertyInfo::fromName(const QString& name)
         { QStringLiteral("genre"), Property::Genre },
         { QStringLiteral("samplerate"), Property::SampleRate },
         { QStringLiteral("tracknumber"), Property::TrackNumber },
+        { QStringLiteral("discnumber"), Property::DiscNumber },
         { QStringLiteral("releaseyear"), Property::ReleaseYear },
         { QStringLiteral("comment"), Property::Comment },
         { QStringLiteral("artist"), Property::Artist },
@@ -530,7 +563,11 @@ PropertyInfo PropertyInfo::fromName(const QString& name)
         { QStringLiteral("translationunitswithdrafttranslation"), Property::TranslationUnitsWithDraftTranslation },
         { QStringLiteral("translationlastauthor"), Property::TranslationLastAuthor },
         { QStringLiteral("translationlastupdate"), Property::TranslationLastUpDate },
-        { QStringLiteral("translationtemplatedate"), Property::TranslationTemplateDate }
+        { QStringLiteral("translationtemplatedate"), Property::TranslationTemplateDate },
+        { QStringLiteral("originurl"), Property::OriginUrl },
+        { QStringLiteral("originemailsubject"), Property::OriginEmailSubject },
+        { QStringLiteral("originemailsender"), Property::OriginEmailSender },
+        { QStringLiteral("originemailmessageid"), Property::OriginEmailMessageId }
     };
 
     return PropertyInfo(propertyHash.value(name.toLower()));
